@@ -10,7 +10,7 @@
 #' @param prior_odds Optional vector of prior odds for the models. See \code{BayesFactor::priorOdds<-}.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @return a data frame containing the prior and posterior probabilities, and BF for each effect.
+#' @return a data frame containing the prior and posterior probabilities, and log(BF) for each effect.
 #'
 #' @details Inclusion Bayes factors answer the question: Are the observed data more
 #' probable under models with a particular effect, than they are under models without
@@ -102,7 +102,7 @@ bayesfactor_inclusion.bayesfactor_models <- function(models, match_models = FALS
     effnames,
     Pinc = rep(NA, length(effnames)),
     PincD = rep(NA, length(effnames)),
-    BF_inclusion = rep(NA, length(effnames)),
+    log_BF = rep(NA, length(effnames)),
     stringsAsFactors = FALSE
   )
 
@@ -136,15 +136,13 @@ bayesfactor_inclusion.bayesfactor_models <- function(models, match_models = FALS
     # Save results
     df.effect$Pinc[effnames == eff] <- mwithprior
     df.effect$PincD[effnames == eff] <- mwithpost
-    df.effect$BF_inclusion[effnames == eff] <- (mwithpost / mwithoutpost) / (mwithprior / mwithoutprior)
+    df.effect$log_BF[effnames == eff] <- (log(mwithpost) - log(mwithoutpost)) - (log(mwithprior) - log(mwithoutprior))
   }
 
-  df.effect$BF_inclusion <- df.effect$BF_inclusion
   df.effect <- df.effect[, -1, drop = FALSE]
-  colnames(df.effect) <- c("p_prior", "p_posterior", "BF")
+  colnames(df.effect) <- c("p_prior", "p_posterior", "log_BF")
   rownames(df.effect) <- effnames
 
-
   class(df.effect) <- c("bayesfactor_inclusion", class(df.effect))
   attr(df.effect, "matched") <- match_models
   attr(df.effect, "priorOdds") <- prior_odds
@@ -178,48 +176,3 @@ bayesfactor_inclusion.BFBayesFactor <- function(models, match_models = FALSE, pr
 
   temp
 }
-
-#' @keywords internal
-.make_terms <- function(formula) {
-  sort_interactions <- function(x) {
-    if (grepl("\\:", x)) {
-      effs <- unlist(strsplit(x, "\\:"))
-      x <- paste0(sort(effs), collapse = ":")
-    }
-    x
-  }
-  formula.f <- stats::as.formula(paste0("~", formula))
-  all.terms <- attr(stats::terms(formula.f), "term.labels")
-
-  # Fixed
-  fix_trms <- all.terms[!grepl("\\|", all.terms)] # no random
-  if (length(fix_trms) > 0) {
-    fix_trms <- sapply(fix_trms, sort_interactions)
-  }
-
-  # Random
-  random_parts <- paste0(all.terms[grepl("\\|", all.terms)]) # only random
-  if (length(random_parts) == 0) {
-    return(fix_trms)
-  }
-  random_units <- sub("^.+\\|\\s+", "", random_parts)
-  tmp_random <- lapply(
-    sub("\\|.+$", "", random_parts),
-    function(x) stats::as.formula(paste0("~", x))
-  )
-
-  rand_trms <- vector("list", length(random_parts))
-
-  for (i in seq_along(random_parts)) {
-    tmp_trms <- attr(stats::terms.formula(tmp_random[[i]]), "term.labels")
-    tmp_trms <- sapply(tmp_trms, sort_interactions)
-
-    if (!any(unlist(strsplit(as.character(tmp_random[[i]])[[2]], " \\+ ")) == "0")) {
-      tmp_trms <- c("1", tmp_trms)
-    }
-
-    rand_trms[[i]] <- paste0(tmp_trms, ":", random_units[[i]])
-  }
-
-  c(fix_trms, unlist(rand_trms))
-}
