@@ -39,8 +39,6 @@ map_estimate <- function(x, precision = 2^10, method = "kernel", ...) {
 
 
 
-
-
 #' @rdname map_estimate
 #' @export
 map_estimate.numeric <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -60,7 +58,6 @@ map_estimate.numeric <- function(x, precision = 2^10, method = "kernel", ...) {
 }
 
 
-
 #' @rdname map_estimate
 #' @export
 map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -69,6 +66,47 @@ map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
 }
 
 
+#' @export
+map_estimate.BGGM <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.mcmc <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.bamlss <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.bcplm <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.blrm <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
+
+#' @export
+map_estimate.mcmc.list <- function(x, precision = 2^10, method = "kernel", ...) {
+  x <- insight::get_parameters(x)
+  map_estimate(x, precision = precision, method = method)
+}
+
 
 #' @importFrom insight get_parameters
 #' @keywords internal
@@ -82,22 +120,23 @@ map_estimate.bayesQR <- function(x, precision = 2^10, method = "kernel", ...) {
     row.names = NULL
   )
 
+  out <- .add_clean_parameters_attribute(out, x)
   attr(out, "MAP_density") <- sapply(l, attr, "MAP_density")
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
   attr(out, "centrality") <- "map"
   class(out) <- unique(c("map_estimate", "see_point_estimate", class(out)))
-
-  class(out) <- unique(c("map_estimate", class(out)))
   out
 }
 
+
 #' @rdname map_estimate
 #' @export
-map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
 
   .map_estimate_models(
-    x = insight::get_parameters(x, effects = effects, parameters = parameters),
+    x = insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
     precision = precision,
     method = method
   )
@@ -106,6 +145,9 @@ map_estimate.stanreg <- function(x, precision = 2^10, method = "kernel", effects
 #' @export
 map_estimate.stanfit <- map_estimate.stanreg
 
+#' @export
+map_estimate.blavaan <- map_estimate.stanreg
+
 
 #' @rdname map_estimate
 #' @export
@@ -120,7 +162,6 @@ map_estimate.brmsfit <- function(x, precision = 2^10, method = "kernel", effects
 }
 
 
-
 #' @rdname map_estimate
 #' @export
 map_estimate.data.frame <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -128,8 +169,6 @@ map_estimate.data.frame <- function(x, precision = 2^10, method = "kernel", ...)
 }
 
 
-
-
 #' @rdname map_estimate
 #' @export
 map_estimate.emmGrid <- function(x, precision = 2^10, method = "kernel", ...) {
@@ -141,6 +180,18 @@ map_estimate.emmGrid <- function(x, precision = 2^10, method = "kernel", ...) {
 map_estimate.emm_list <- map_estimate.emmGrid
 
 
+#' @export
+map_estimate.get_predicted <- function(x, ...) {
+  if ("iterations" %in% names(attributes(x))) {
+    map_estimate(as.data.frame(t(attributes(x)$iterations)), ...)
+  } else {
+    stop("No iterations present in the output.")
+  }
+}
+
+# Methods -----------------------------------------------------------------
+
+
 
 #' @rdname as.numeric.p_direction
 #' @method as.numeric map_estimate
