@@ -67,8 +67,9 @@ p_rope.MCMCglmm <- p_rope.numeric
 
 #' @rdname p_rope
 #' @export
-p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
-  out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, parameters = parameters, ...))
+p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
+  out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, component = component, parameters = parameters, ...))
+  out <- .add_clean_parameters_attribute(out, x)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
@@ -76,11 +77,15 @@ p_rope.stanreg <- function(x, range = "default", effects = c("fixed", "random",
 #' @export
 p_rope.stanfit <- p_rope.stanreg
 
+#' @export
+p_rope.blavaan <- p_rope.stanreg
+
 
 #' @rdname p_rope
 #' @export
 p_rope.brmsfit <- function(x, range = "default", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, effects = effects, component = component, parameters = parameters, ...))
+  out <- .add_clean_parameters_attribute(out, x)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
 }
@@ -97,6 +102,15 @@ p_rope.sim <- function(x, range = "default", parameters = NULL, ...) {
   out
 }
 
+#' @export
+p_rope.bamlss <- function(x, range = "default", component = c("all", "conditional", "location"), parameters = NULL, ...) {
+  component <- match.arg(component)
+  out <- .p_rope(rope(x, range = range, ci = 1, effects = "all", component = component, parameters = parameters, ...))
+  out <- .add_clean_parameters_attribute(out, x)
+  attr(out, "object_name") <- .safe_deparse(substitute(x))
+  out
+}
+
 #' @export
 p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
   out <- .p_rope(rope(x, range = range, ci = 1, parameters = parameters, ...))
@@ -107,6 +121,12 @@ p_rope.mcmc <- function(x, range = "default", parameters = NULL, ...) {
 #' @export
 p_rope.bcplm <- p_rope.mcmc
 
+#' @export
+p_rope.BGGM <- p_rope.mcmc
+
+#' @export
+p_rope.blrm <- p_rope.mcmc
+
 #' @export
 p_rope.mcmc.list <- p_rope.mcmc
 
