@@ -154,22 +154,30 @@ p_significance.mcmc <- function(x, threshold = "default", ...) {
 }
 
 
+#' @export
+p_significance.bamlss <- function(x, threshold = "default", component = c("all", "conditional", "location"), ...) {
+  out <- p_significance(insight::get_parameters(x, component = component), threshold = threshold, ...)
+  out <- .add_clean_parameters_attribute(out, x)
+  out
+}
+
+
 #' @export
 p_significance.bcplm <- function(x, threshold = "default", ...) {
   p_significance(insight::get_parameters(x), threshold = threshold, ...)
 }
 
+#' @export
+p_significance.mcmc.list <- p_significance.bcplm
 
 #' @export
-p_significance.mcmc.list <- function(x, threshold = "default", ...) {
-  p_significance(insight::get_parameters(x), threshold = threshold, ...)
-}
-
+p_significance.bayesQR <- p_significance.bcplm
 
 #' @export
-p_significance.bayesQR <- function(x, threshold = "default", ...) {
-  p_significance(insight::get_parameters(x), threshold = threshold, ...)
-}
+p_significance.blrm <- p_significance.bcplm
+
+#' @export
+p_significance.BGGM <- p_significance.bcplm
 
 
 #' @rdname p_significance
@@ -193,17 +201,20 @@ p_significance.emm_list <- p_significance.emmGrid
 
 #' @rdname p_significance
 #' @export
-p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
   threshold <- .select_threshold_ps(model = x, threshold = threshold)
 
   data <- p_significance(
-    insight::get_parameters(x, effects = effects, parameters = parameters),
+    insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
     threshold = threshold
   )
 
-  out <- .prepare_output(data, insight::clean_parameters(x), inherits(x, "stanmvreg"))
+  cleaned_parameters <- insight::clean_parameters(x)
+  out <- .prepare_output(data, cleaned_parameters, inherits(x, "stanmvreg"))
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- class(data)
@@ -215,6 +226,10 @@ p_significance.stanreg <- function(x, threshold = "default", effects = c("fixed"
 p_significance.stanfit <- p_significance.stanreg
 
 
+#' @export
+p_significance.blavaan <- p_significance.stanreg
+
+
 
 
 
@@ -230,8 +245,10 @@ p_significance.brmsfit <- function(x, threshold = "default", effects = c("fixed"
     threshold = threshold
   )
 
-  out <- .prepare_output(data, insight::clean_parameters(x))
+  cleaned_parameters <- insight::clean_parameters(x)
+  out <- .prepare_output(data, cleaned_parameters)
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   attr(out, "threshold") <- threshold
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   class(out) <- class(data)
