@@ -3,7 +3,14 @@
 #' Compute the proportion of the HDI (default to the 89\% HDI) of a posterior distribution that lies within a region of practical equivalence.
 #'
 #' @param x Vector representing a posterior distribution. Can also be a \code{stanreg} or \code{brmsfit} model.
-#' @param range ROPE's lower and higher bounds. Should be a vector of length two (e.g., \code{c(-0.1, 0.1)}) or \code{"default"}. If \code{"default"}, the range is set to \code{c(-0.1, 0.1)} if input is a vector, and based on \code{\link[=rope_range]{rope_range()}} if a Bayesian model is provided.
+#' @param range ROPE's lower and higher bounds. Should be \code{"default"} or
+#' depending on the number of outcome variables a vector or a list. In models with one response,
+#' `range` should be a vector of length two (e.g., \code{c(-0.1, 0.1)}). In
+#' multivariate models, `range` should be a list with a numeric vectors for
+#' each response variable. Vector names should correspond to the name of the response
+#' variables. If \code{"default"} and input is a vector, the range is set to \code{c(-0.1,
+#' 0.1)}. If \code{"default"} and input is a Bayesian model,
+#' \code{\link[=rope_range]{rope_range()}} is used.
 #' @param ci The Credible Interval (CI) probability, corresponding to the proportion of HDI, to use for the percentage in ROPE.
 #' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See \code{\link{ci}}.
 #'
@@ -95,6 +102,11 @@
 #' rope(model)
 #' rope(model, ci = c(.90, .95))
 #'
+#' library(brms)
+#' model <- brms::brm(brms::mvbind(mpg, disp) ~ wt + cyl, data = mtcars)
+#' rope(model)
+#' rope(model, ci = c(.90, .95))
+#'
 #' library(BayesFactor)
 #' bf <- ttestBF(x = rnorm(100, 1, 1))
 #' rope(bf)
@@ -125,7 +137,7 @@ rope.default <- function(x, ...) {
 
 #' @rdname rope
 #' @export
-rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.numeric <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   if (all(range == "default")) {
     range <- c(-0.1, 0.1)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
@@ -146,7 +158,7 @@ rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verb
   }
 
   # Attributes
-  hdi_area <- cbind(CI = ci * 100, data.frame(do.call(rbind, lapply(rope_values, attr, "HDI_area"))))
+  hdi_area <- cbind(CI = ci, data.frame(do.call(rbind, lapply(rope_values, attr, "HDI_area"))))
   names(hdi_area) <- c("CI", "CI_low", "CI_high")
 
   attr(out, "HDI_area") <- hdi_area
@@ -162,7 +174,7 @@ rope.numeric <- function(x, range = "default", ci = .89, ci_method = "HDI", verb
 
 #' @rdname rope
 #' @export
-rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   out <- .prepare_rope_df(x, range, ci, ci_method, verbose)
   HDI_area_attributes <- .compact_list(out$HDI_area)
   dat <- data.frame(
@@ -183,7 +195,7 @@ rope.data.frame <- function(x, range = "default", ci = .89, ci_method = "HDI", v
 
 #' @rdname rope
 #' @export
-rope.emmGrid <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.emmGrid <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   xdf <- insight::get_parameters(x)
 
   dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
@@ -198,9 +210,9 @@ rope.emm_list <- rope.emmGrid
 
 #' @rdname rope
 #' @export
-rope.BFBayesFactor <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   }
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -214,7 +226,7 @@ rope.bamlss <- rope.BFBayesFactor
 
 #' @rdname rope
 #' @export
-rope.MCMCglmm <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
   out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -223,7 +235,7 @@ rope.MCMCglmm <- function(x, range = "default", ci = .89, ci_method = "HDI", ver
 
 
 #' @export
-rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   out <- rope(as.data.frame(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
   attr(out, "data") <- .safe_deparse(substitute(x))
@@ -234,32 +246,29 @@ rope.mcmc <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose
 
 
 #' @export
-rope.bcplm <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
+rope.bcplm <- function(x, range = "default", ci = 0.95, ci_method = "HDI", verbose = TRUE, ...) {
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
   attr(out, "data") <- .safe_deparse(substitute(x))
   out
 }
 
-
-
+#' @export
+rope.bayesQR <- rope.bcplm
 
 #' @export
-rope.bayesQR <- function(x, range = "default", ci = .89, ci_method = "HDI", verbose = TRUE, ...) {
-  out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(out, "object_name") <- NULL
-  attr(out, "data") <- .safe_deparse(substitute(x))
-  out
-}
-
+rope.blrm <- rope.bcplm
 
 #' @export
-rope.mcmc.list <- rope.bayesQR
+rope.BGGM <- rope.bcplm
+
+#' @export
+rope.mcmc.list <- rope.bcplm
 
 
 
 #' @keywords internal
-.rope <- function(x, range = c(-0.1, 0.1), ci = .89, ci_method = "HDI", verbose = TRUE) {
+.rope <- function(x, range = c(-0.1, 0.1), ci = 0.95, ci_method = "HDI", verbose = TRUE) {
   ci_bounds <- ci(x, ci = ci, method = ci_method, verbose = verbose)
 
   if (anyNA(ci_bounds)) {
@@ -272,7 +281,7 @@ rope.mcmc.list <- rope.bayesQR
 
 
   rope <- data.frame(
-    "CI" = ci * 100,
+    "CI" = ci,
     "ROPE_low" = range[1],
     "ROPE_high" = range[2],
     "ROPE_Percentage" = rope_percentage
@@ -288,18 +297,18 @@ rope.mcmc.list <- rope.bayesQR
 
 #' @rdname rope
 #' @export
-rope.stanreg <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
+rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
 
   # check for possible collinearity that might bias ROPE
-  if (verbose) .check_multicollinearity(x, "rope")
+  if (verbose && !inherits(x, "blavaan")) .check_multicollinearity(x, "rope")
 
   rope_data <- rope(
     insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
@@ -322,36 +331,81 @@ rope.stanreg <- function(x, range = "default", ci = .89, ci_method = "HDI", effe
 #' @export
 rope.stanfit <- rope.stanreg
 
+#' @export
+rope.blavaan <- rope.stanreg
+
 
 #' @rdname rope
 #' @export
-rope.brmsfit <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, ...) {
+rope.brmsfit <- function(x,
+                         range = "default",
+                         ci = 0.95,
+                         ci_method = "HDI",
+                         effects = c("fixed", "random", "all"),
+                         component = c("conditional", "zi", "zero_inflated", "all"),
+                         parameters = NULL,
+                         verbose = TRUE,
+                         ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  if (insight::is_multivariate(x)) {
-    stop("Multivariate response models are not yet supported.")
-  }
-
+  # check range argument
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
+    # we expect a list with named vectors (length two) in the multivariate case.
+    # Names state the response variable.
+  } else if (insight::is_multivariate(x) &&
+    (!is.list(range) || length(range) != length(insight::find_response(x)) ||
+      names(range) != insight::find_response(x))) {
+    stop("With a multivariate model, `range` should be 'default' or a list of named numeric vectors with length 2.")
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
 
-  # check for possible collinearity that might bias ROPE
+  # check for possible collinearity that might bias ROPE and print a warning
   if (verbose) .check_multicollinearity(x, "rope")
 
-  rope_data <- rope(
-    insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
-    range = range,
-    ci = ci,
-    ci_method = ci_method,
-    verbose = verbose,
-    ...
-  )
+  # calc rope
+  if (insight::is_multivariate(x)) {
+    dv <- insight::find_response(x)
 
-  out <- .prepare_output(rope_data, insight::clean_parameters(x))
+    # ROPE range / width differs between response varialbe. Thus ROPE is
+    # calculated for every variable on its own.
+    rope_data <- lapply(
+      dv,
+      function(dv_item) {
+        ret <- rope(
+          insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+          range = range[[dv_item]],
+          ci = ci,
+          ci_method = ci_method,
+          verbose = verbose,
+          ...
+        )
+
+        # It's a waste of performance to calculate ROPE for all parameters
+        # with the ROPE width of a specific response variable and to throw
+        # away the unwanted results. However, performance impact should not be
+        # too high and this way it is much easier to handle the `parameters`
+        # argument.
+        ret[grepl(paste0("(.*)", dv_item), ret$Parameter), ]
+      }
+    )
+    rope_data <- do.call(rbind, rope_data)
+
+    out <- .prepare_output(rope_data, insight::clean_parameters(x), is_brms_mv = TRUE)
+  } else {
+    rope_data <- rope(
+      insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+      range = range,
+      ci = ci,
+      ci_method = ci_method,
+      verbose = verbose,
+      ...
+    )
+
+    out <- .prepare_output(rope_data, insight::clean_parameters(x))
+  }
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
   attr(out, "object_name") <- .safe_deparse(substitute(x))
@@ -363,11 +417,11 @@ rope.brmsfit <- function(x, range = "default", ci = .89, ci_method = "HDI", effe
 
 
 #' @export
-rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
+rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "HDI", effects = c("fixed", "random", "all"), parameters = NULL, verbose = TRUE, ...) {
   effects <- match.arg(effects)
 
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
@@ -399,8 +453,7 @@ rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", e
 
   dat <- do.call(rbind, args = c(.compact_list(list), make.row.names = FALSE))
 
-  dat <- switch(
-    effects,
+  dat <- switch(effects,
     fixed = .select_rows(dat, "Group", "fixed"),
     random = .select_rows(dat, "Group", "random"),
     dat
@@ -427,9 +480,9 @@ rope.sim.merMod <- function(x, range = "default", ci = .89, ci_method = "HDI", e
 
 
 #' @export
-rope.sim <- function(x, range = "default", ci = .89, ci_method = "HDI", parameters = NULL, verbose = TRUE, ...) {
+rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "HDI", parameters = NULL, verbose = TRUE, ...) {
   if (all(range == "default")) {
-    range <- rope_range(x)
+    range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
     stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
