@@ -24,8 +24,8 @@ if (require("testthat")) {
 
     expect_equal(bfr$p_prior, c(0.2, 0.5), tolerance = 0.1)
     expect_equal(bfr$p_posterior, c(0.31, 1), tolerance = 0.1)
-    expect_equal(log(bfr$BF), c(0.43, 0.69), tolerance = 0.1)
-    expect_equal(bfr$BF, bfr$p_posterior / bfr$p_prior, tolerance = 0.1)
+    expect_equal(bfr$log_BF, c(0.43, 0.69), tolerance = 0.1)
+    expect_equal(exp(bfr$log_BF), bfr$p_posterior / bfr$p_prior, tolerance = 0.1)
 
     expect_error(bayesfactor_restricted(posterior, prior, hypothesis = "Y < 0"))
   })
